summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorSimon Rettberg2024-02-02 15:18:00 +0100
committerSimon Rettberg2024-02-02 15:18:18 +0100
commit8bab5609a06d7f12c3fd5e3c30af074994e3d50b (patch)
treef1c34ac2f381b6a4fc2757987776dd8313da452f
parent[slx-addons] Optimize addon activation (~1000% gain) (diff)
downloadsystemd-init-8bab5609a06d7f12c3fd5e3c30af074994e3d50b.tar.gz
systemd-init-8bab5609a06d7f12c3fd5e3c30af074994e3d50b.tar.xz
systemd-init-8bab5609a06d7f12c3fd5e3c30af074994e3d50b.zip
[dnbd3-rootfs] Make sure to copy dnbd3-client binary again
Somehow this got MIA in the big refactor.
-rwxr-xr-xmodules.d/dnbd3-rootfs/hooks/copy-dracut-systemd-files-into-newroot.sh12
1 files changed, 8 insertions, 4 deletions
diff --git a/modules.d/dnbd3-rootfs/hooks/copy-dracut-systemd-files-into-newroot.sh b/modules.d/dnbd3-rootfs/hooks/copy-dracut-systemd-files-into-newroot.sh
index 58f23207..007b950d 100755
--- a/modules.d/dnbd3-rootfs/hooks/copy-dracut-systemd-files-into-newroot.sh
+++ b/modules.d/dnbd3-rootfs/hooks/copy-dracut-systemd-files-into-newroot.sh
@@ -1,8 +1,12 @@
-#!/usr/bin/env bash
-# -*- coding: utf-8 -*-
-type emergency_shell >/dev/null 2>&1 || source /lib/dracut-lib.sh
+#!/bin/bash
-# Copy out services over to stage 4, so they still appear in
+type emergency_shell &>/dev/null || source /lib/dracut-lib.sh
+
+# Copy dnbd3-client too, needed for controlling dnbd0
+mkdir -p "${NEWROOT}/opt/openslx/sbin"
+cp "$(which dnbd3-client)" "${NEWROOT}/opt/openslx/sbin/dnbd3-client"
+
+# Copy our services over to stage 4, so they still appear in
# systemd-analyze plot etc.
new_systemd_system_unit_path="${NEWROOT}/lib/systemd/system"